diff --git a/sf_entity/sf_entity.module b/sf_entity/sf_entity.module
index b65a126..1383f44 100644
--- a/sf_entity/sf_entity.module
+++ b/sf_entity/sf_entity.module
@@ -774,7 +774,7 @@ function sf_entity_export($entity, $name, $sfid = NULL) {
   // Allow modules to alter the Salesforce object and fieldmap prior to export.
   foreach (module_implements('salesforce_api_pre_export') as $module) {
     $function = $module . '_salesforce_api_pre_export';
-    $continue = $function($object, $map, $id);
+    $continue = $function($object, $map, $entity);
     if ($continue === FALSE) {
       return;
     }
@@ -848,7 +848,7 @@ function sf_entity_export($entity, $name, $sfid = NULL) {
       WATCHDOG_ERROR, l('entity ' . $id, entity_uri($map->drupal_entity, $entity)));
   }
   // Allow other modules to respond after an export.
-  module_invoke_all('salesforce_api_post_export', $object, $map, $id, $response);
+  module_invoke_all('salesforce_api_post_export', $object, $map, $entity, $response);
   // Return the status of the export.
   $result = (isset($response->success) && $response->success == TRUE) ? TRUE : FALSE;
   return $result;

diff --git a/salesforce_api.api.php b/salesforce_api.api.php
index ad3a2b5..29571c6 100644
--- a/salesforce_api.api.php
+++ b/salesforce_api.api.php
@@ -229,14 +229,14 @@ function hook_salesforce_api_id_save_alter(&$oid, &$sfid, &$name, &$entity_name,
  *   The object about to be exported to Salesforce
  * @param object $map
  *   The fieldmap object provided by salesforce_api_fieldmap_load().
  * @param string $drupal_id 
  *   The unique Id of the drupal entity associated with the sf_object, e.g. nid
  * @return
  *   Implementing modules should return FALSE if the current export should NOT
  *   proceed. Note that this will prevent further processing of implementations
  *   of this hook.
  */
-function hook_salesforce_api_pre_export(&$sf_object, &$map, $drupal_id) {
+function hook_salesforce_api_pre_export(&$sf_object, &$map, $drupal_entity) {
 
 }
 
@@ -248,7 +248,7 @@ function hook_salesforce_api_pre_export(&$sf_object, &$map, $drupal_id) {
  *  The object exported to Salesforce.
  * @param string $name
  *  The fieldmap name.
- * @param string $drupal_id 
+ * @param object $drupal_entity
  * @param object $salesforce_response
  *   The response object from the Salesforce SOAP server. This object has three
  *   properties:
@@ -261,7 +261,7 @@ function hook_salesforce_api_pre_export(&$sf_object, &$map, $drupal_id) {
  *   - success: boolean
  * @return void
  */
-function hook_salesforce_api_post_export($sf_object, $name, $drupal_id, $salesforce_response) {
+function hook_salesforce_api_post_export($sf_object, $name, $drupal_entity, $salesforce_response) {
   
 }
 
@@ -229,14 +229,14 @@ function hook_salesforce_api_id_save_alter(&$oid, &$sfid, &$name, &$entity_name,
  * @param object $map
  *   The fieldmap object provided by salesforce_api_fieldmap_load().
- * @param string $drupal_id 
- *   The unique Id of the drupal entity associated with the sf_object, e.g. nid
+ * @param object $drupal_entity
+ *   The fully-loaded drupal entity associated with the sf_object, e.g. $user
  * @return
  *   Implementing modules should return FALSE if the current export should NOT